"""BraviaTV exceptions."""


class BraviaTVError(Exception):
    """Base BraviaTV exception."""


class BraviaTVAuthError(BraviaTVError):
    """Raised to indicate auth error."""


class BraviaTVNotFound(BraviaTVError):
    """Raised to indicate not found error."""


class BraviaTVNotSupported(BraviaTVError):
    """Raised to indicate not supported error."""


class BraviaTVConnectionError(BraviaTVError):
    """Raised to indicate connection error."""


class BraviaTVConnectionTimeout(BraviaTVError):
    """Raised to indicate connection timeout."""



"""Python library for remote control of Sony Bravia TV."""
# flake8: noqa
from .client import BraviaTV
from .exceptions import (
    BraviaTVAuthError,
    BraviaTVConnectionError,
    BraviaTVConnectionTimeout,
    BraviaTVError,
    BraviaTVNotFound,
    BraviaTVNotSupported,
)

__version__ = "0.2.1"
